Struct SampledBitSetStrategy
pub struct SampledBitSetStrategy<T>where
T: BitSetLike,{
size: SizeRange,
bits: SizeRange,
_marker: PhantomData<T>,
}Expand description
Generates bit sets with a particular number of bits set.
Specifically, this strategy is given both a size range and a bit range. To produce a new value, it selects a size, then uniformly selects that many bits from within the bit range.
Shrinking happens as with BitSetStrategy.
Fields
size: SizeRangebits: SizeRange_marker: PhantomData<T>Implementations
impl<T> SampledBitSetStrategy<T>where
T: BitSetLike,
impl<T> SampledBitSetStrategy<T>where
T: BitSetLike,
pub fn new(
size: impl Into<SizeRange>,
bits: impl Into<SizeRange>,
) -> SampledBitSetStrategy<T>
pub fn new( size: impl Into<SizeRange>, bits: impl Into<SizeRange>, ) -> SampledBitSetStrategy<T>
Create a strategy which generates values where bits within the bounds
given by bits may be set. The number of bits that are set is chosen
to be in the range given by size.
Due to the generics, the functions in the typed submodules are usually preferable to calling this directly.
Panics
Panics if size includes a value that is greater than the number of
bits in bits.